==> jc-1.4.0.tar.gz: polyglot/visit/AscriptionVisitor.h <==
// public class polyglot.visit.AscriptionVisitor

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f8e2af057551681 polyglot_visit_AscriptionVisitor
// @dep_class 5c18e1d62fddfa29 polyglot_visit_ContextVisitor
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_ContextVisitor

#include "polyglot/visit/ContextVisitor.h"

#ifndef _JC_polyglot_visit_AscriptionVisitor_H_
#define _JC_polyglot_visit_AscriptionVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_AscriptionVisitor$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_AscriptionVisitor$sub_refs	_jc_polyglot_visit_AscriptionVisitor$sub_refs;
typedef struct _jc_polyglot_visit_AscriptionVisitor$sub_nonrefs	_jc_polyglot_visit_AscriptionVisitor$sub_nonrefs;
typedef struct _jc_polyglot_visit_AscriptionVisitor$refs	_jc_polyglot_visit_AscriptionVisitor$refs;
typedef struct _jc_polyglot_visit_AscriptionVisitor$nonrefs	_jc_polyglot_visit_AscriptionVisitor$nonrefs;
typedef struct _jc_polyglot_visit_AscriptionVisitor$object	_jc_polyglot_visit_AscriptionVisitor$object;

typedef const struct _jc_polyglot_visit_AscriptionVisitor$vmethods	_jc_polyglot_visit_AscriptionVisitor$vmethods;
typedef const struct _jc_polyglot_visit_AscriptionVisitor$vtable	_jc_polyglot_visit_AscriptionVisitor$vtable;
typedef const struct _jc_polyglot_visit_AscriptionVisitor$vtype	_jc_polyglot_visit_AscriptionVisitor$vtype;

// Constructors
extern void _jc_polyglot_visit_AscriptionVisitor$method$_init$dac7f764f0e12933(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_visit_AscriptionVisitor$method$ascribe$51a47bc56f6458ea(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_AscriptionVisitor$method$enterCall$3637fb21939178bc(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_visit_AscriptionVisitor$method$leaveCall$9236e830bcef4b36(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
extern struct _jc_polyglot_visit_AscriptionVisitor$object *_jc_polyglot_visit_AscriptionVisitor$method$pop$61515fcefaa8b11d(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *);
extern struct _jc_object *_jc_polyglot_visit_AscriptionVisitor$method$toType$4dd5ac4b101dcd1f(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_AscriptionVisitor$method_info$ascribe$51a47bc56f6458ea;
extern _jc_method _jc_polyglot_visit_AscriptionVisitor$method_info$enterCall$3637fb21939178bc;
extern _jc_method _jc_polyglot_visit_AscriptionVisitor$method_info$leaveCall$9236e830bcef4b36;
extern _jc_method _jc_polyglot_visit_AscriptionVisitor$method_info$pop$61515fcefaa8b11d;
extern _jc_method _jc_polyglot_visit_AscriptionVisitor$method_info$toType$4dd5ac4b101dcd1f;

// Virtual methods structure
struct _jc_polyglot_visit_AscriptionVisitor$vmethods {
	struct _jc_object	*(*ascribe$51a47bc56f6458ea)(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enterCall$3637fb21939178bc)(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_object	*(*leaveCall$9236e830bcef4b36)(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
	struct _jc_polyglot_visit_AscriptionVisitor$object	*(*pop$61515fcefaa8b11d)(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *);
	struct _jc_object	*(*toType$4dd5ac4b101dcd1f)(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *);
};

// Vtable
struct _jc_polyglot_visit_AscriptionVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_ContextVisitor$vmethods	polyglot_visit_ContextVisitor;
	_jc_polyglot_visit_AscriptionVisitor$vmethods	polyglot_visit_AscriptionVisitor;
};

// Vtype
struct _jc_polyglot_visit_AscriptionVisitor$vtype {
	_jc_type			type;
	_jc_polyglot_visit_AscriptionVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_AscriptionVisitor$sub_refs {
	struct _jc_object	*type;
	struct _jc_polyglot_visit_AscriptionVisitor$object	*outer;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_AscriptionVisitor$refs {
    _jc_polyglot_visit_AscriptionVisitor$sub_refs	polyglot_visit_AscriptionVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_refs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_AscriptionVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_AscriptionVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_nonrefs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_AscriptionVisitor$sub_nonrefs	polyglot_visit_AscriptionVisitor;
};

// Object instance structure
struct _jc_polyglot_visit_AscriptionVisitor$object {
	_jc_polyglot_visit_AscriptionVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_AscriptionVisitor$vtype	*vtype;
	_jc_polyglot_visit_AscriptionVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_AscriptionVisitor$vtype _jc_polyglot_visit_AscriptionVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_AscriptionVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_AscriptionVisitor$class_object;

#endif	/* _JC_polyglot_visit_AscriptionVisitor_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/AscriptionVisitor.h <==
// public class polyglot.visit.AscriptionVisitor

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f8e2af057551681 polyglot_visit_AscriptionVisitor
// @dep_class 5c18e1d62fddfa29 polyglot_visit_ContextVisitor
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_ContextVisitor

#include "polyglot/visit/ContextVisitor.h"

#ifndef _JC_polyglot_visit_AscriptionVisitor_H_
#define _JC_polyglot_visit_AscriptionVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_AscriptionVisitor$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_AscriptionVisitor$sub_refs	_jc_polyglot_visit_AscriptionVisitor$sub_refs;
typedef struct _jc_polyglot_visit_AscriptionVisitor$sub_nonrefs	_jc_polyglot_visit_AscriptionVisitor$sub_nonrefs;
typedef struct _jc_polyglot_visit_AscriptionVisitor$refs	_jc_polyglot_visit_AscriptionVisitor$refs;
typedef struct _jc_polyglot_visit_AscriptionVisitor$nonrefs	_jc_polyglot_visit_AscriptionVisitor$nonrefs;
typedef struct _jc_polyglot_visit_AscriptionVisitor$object	_jc_polyglot_visit_AscriptionVisitor$object;

typedef const struct _jc_polyglot_visit_AscriptionVisitor$vmethods	_jc_polyglot_visit_AscriptionVisitor$vmethods;
typedef const struct _jc_polyglot_visit_AscriptionVisitor$vtable	_jc_polyglot_visit_AscriptionVisitor$vtable;
typedef const struct _jc_polyglot_visit_AscriptionVisitor$vtype	_jc_polyglot_visit_AscriptionVisitor$vtype;

// Constructors
extern void _jc_polyglot_visit_AscriptionVisitor$method$_init$dac7f764f0e12933(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_visit_AscriptionVisitor$method$ascribe$51a47bc56f6458ea(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_AscriptionVisitor$method$enterCall$3637fb21939178bc(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_AscriptionVisitor$method$leaveCall$9236e830bcef4b36(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_AscriptionVisitor$object *_jc_polyglot_visit_AscriptionVisitor$method$pop$61515fcefaa8b11d(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_AscriptionVisitor$method$toType$4dd5ac4b101dcd1f(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_AscriptionVisitor$method_info$ascribe$51a47bc56f6458ea;
extern _jc_method _jc_polyglot_visit_AscriptionVisitor$method_info$enterCall$3637fb21939178bc;
extern _jc_method _jc_polyglot_visit_AscriptionVisitor$method_info$leaveCall$9236e830bcef4b36;
extern _jc_method _jc_polyglot_visit_AscriptionVisitor$method_info$pop$61515fcefaa8b11d;
extern _jc_method _jc_polyglot_visit_AscriptionVisitor$method_info$toType$4dd5ac4b101dcd1f;

// Virtual methods structure
struct _jc_polyglot_visit_AscriptionVisitor$vmethods {
	struct _jc_object	*(*ascribe$51a47bc56f6458ea)(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enterCall$3637fb21939178bc)(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leaveCall$9236e830bcef4b36)(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_AscriptionVisitor$object	*(*pop$61515fcefaa8b11d)(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*toType$4dd5ac4b101dcd1f)(_jc_env *, struct _jc_polyglot_visit_AscriptionVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_AscriptionVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_ContextVisitor$vmethods	polyglot_visit_ContextVisitor;
	_jc_polyglot_visit_AscriptionVisitor$vmethods	polyglot_visit_AscriptionVisitor;
};

// Vtype
struct _jc_polyglot_visit_AscriptionVisitor$vtype {
	_jc_type			type;
	_jc_polyglot_visit_AscriptionVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_AscriptionVisitor$sub_refs {
	struct _jc_object	*type;
	struct _jc_polyglot_visit_AscriptionVisitor$object	*outer;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_AscriptionVisitor$refs {
    _jc_polyglot_visit_AscriptionVisitor$sub_refs	polyglot_visit_AscriptionVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_refs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_AscriptionVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_AscriptionVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_nonrefs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_AscriptionVisitor$sub_nonrefs	polyglot_visit_AscriptionVisitor;
};

// Object instance structure
struct _jc_polyglot_visit_AscriptionVisitor$object {
	_jc_polyglot_visit_AscriptionVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_AscriptionVisitor$vtype	*vtype;
	_jc_polyglot_visit_AscriptionVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_AscriptionVisitor$vtype _jc_polyglot_visit_AscriptionVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_AscriptionVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_AscriptionVisitor$class_object;

#endif	/* _JC_polyglot_visit_AscriptionVisitor_H_ */
